==> jv-beans-0.1.0-all.zip: jv-beans-0.1.0/src/org/stormcat/jvbeans/dto/child/TrioOddsDto.java <==
/*
 * Copyright 2009 the Stormcat Project.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.stormcat.jvbeans.dto.child;
 
 /**
 * @author jv-beans-gen
 *
 */
public class TrioOddsDto {

    /** 　　組番 */
    @org.stormcat.jvbeans.annotation.JvProperty(position = 1, byteLength = 6)
    private java.lang.String pairNo;

    /** 　　オッズ */
    @org.stormcat.jvbeans.annotation.JvProperty(position = 7, byteLength = 6)
    private java.lang.String odds;

    /** 　　人気順 */
    @org.stormcat.jvbeans.annotation.JvProperty(position = 13, byteLength = 3)
    private java.lang.Integer betRank;


    /**
     * @return 　　組番
     */
    public java.lang.String getPairNo() {
        return pairNo;
    }
    
    /**
     * @param pairNo 　　組番
     */
    public void setPairNo(java.lang.String pairNo) {
        this.pairNo = pairNo;
    }    
    
    /**
     * @return 　　オッズ
     */
    public java.lang.String getOdds() {
        return odds;
    }
    
    /**
     * @param odds 　　オッズ
     */
    public void setOdds(java.lang.String odds) {
        this.odds = odds;
    }    
    
    /**
     * @return 　　人気順
     */
    public java.lang.Integer getBetRank() {
        return betRank;
    }
    
    /**
     * @param betRank 　　人気順
     */
    public void setBetRank(java.lang.Integer betRank) {
        this.betRank = betRank;
    }    
    
}

==> jv-beans-0.1.2-all.zip: jv-beans-0.1.2/src/org/stormcat/jvbeans/dto/child/TrioOddsDto.java <==
/*
 * Copyright 2009 the Stormcat Project.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.stormcat.jvbeans.dto.child;
 
 /**
 * @author jv-beans-gen
 *
 */
public class TrioOddsDto {

    /** 　　組番 */
    @org.stormcat.jvbeans.annotation.JvProperty(position = 1, byteLength = 6)
    private java.lang.String pairNo;

    /** 　　オッズ */
    @org.stormcat.jvbeans.annotation.JvProperty(position = 7, byteLength = 6)
    private java.lang.String odds;

    /** 　　人気順 */
    @org.stormcat.jvbeans.annotation.JvProperty(position = 13, byteLength = 3)
    private java.lang.String betRank;


    /**
     * @return 　　組番
     */
    public java.lang.String getPairNo() {
        return pairNo;
    }
    
    /**
     * @param pairNo 　　組番
     */
    public void setPairNo(java.lang.String pairNo) {
        this.pairNo = pairNo;
    }    
    
    /**
     * @return 　　オッズ
     */
    public java.lang.String getOdds() {
        return odds;
    }
    
    /**
     * @param odds 　　オッズ
     */
    public void setOdds(java.lang.String odds) {
        this.odds = odds;
    }    
    
    /**
     * @return 　　人気順
     */
    public java.lang.String getBetRank() {
        return betRank;
    }
    
    /**
     * @param betRank 　　人気順
     */
    public void setBetRank(java.lang.String betRank) {
        this.betRank = betRank;
    }    
    
}
